@@ -1,5 +1,5 @@
 package Date::Holidays::BY;
-our $VERSION = '0.2019.5'; # VERSION
+our $VERSION = '0.2020.0'; # VERSION
 
 =encoding utf8
 
@@ -50,7 +50,6 @@ our @EXPORT_OK = qw(
     is_business_day
     is_short_business_day
 );
-use vars qw($strict $HOLIDAYS_VALID_SINCE $INACCURATE_TIMES_SINCE);
 
 =head2 $Date::Holidays::BY::HOLIDAYS_VALID_SINCE, $Date::Holidays::BY::INACCURATE_TIMES_SINCE
 
@@ -59,8 +58,8 @@ INACCURATE_TIMES_SINCE after this year dates of holidays and working day shift a
 
 =cut
 
-$HOLIDAYS_VALID_SINCE = 2017; # TODO add all old
-$INACCURATE_TIMES_SINCE = 2020;
+our $HOLIDAYS_VALID_SINCE = 2017; # TODO add all old
+our $INACCURATE_TIMES_SINCE = 2020;
 
 
 =head2 $Date::Holidays::BY::strict
@@ -70,7 +69,7 @@ Default is 0.
 
 =cut
 
-$strict = 0;
+our $strict = 0;
 
 use Carp;
 use Time::Piece;
@@ -117,18 +116,21 @@ my %HOLIDAYS_SPECIAL = (
     2017 => [ qw( 0102 0424 0425 0508 1106) ],
     2018 => [ qw( 0102 0309 0416 0417 0430 0702 1224 1231) ],
     2019 => [ qw( 0506 0507 0508 1108) ],
+    2020 => [ qw( 0102 0106 0427 0428) ],
 );
 
 my %BUSINESS_DAYS_ON_WEEKENDS = (
     2017 => [ qw( 0121 0429 0506 1104) ],
     2018 => [ qw( 0120 0303 0414 0428 0707 1222 1229) ],
 	2019 => [ qw( 0504 0511 1116) ],
+	2020 => [ qw( 0104 0111 0404) ],
 );
 
 my %SHORT_BUSINESS_DAYS = (
     2017 => [ qw( 0106 0307 0429 0506 1104) ],
     2018 => [ qw( 0307 0508 1106) ],
     2019 => [ qw( 0307 0430 0506 0702 1106 1224) ],
+	2020 => [ qw( ) ],
 );
 
 
@@ -261,7 +263,7 @@ sub _get_date_key {
 
 =head1 LICENSE
 
-This software is copyright (c) 2019 by Vladimir Varlamov.
+This software is copyright (c) 2020 by Vladimir Varlamov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
